@@ -30,14 +30,12 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-"""
-|UDM| module for Portal settings
-"""
+"""|UDM| module for Portal settings"""
 
 import univention.admin.handlers
 import univention.admin.handlers.settings.portal
-import univention.admin.handlers.settings.portal_entry
 import univention.admin.handlers.settings.portal_category
+import univention.admin.handlers.settings.portal_entry
 from univention.admin.layout import Tab
 
 
@@ -52,38 +50,38 @@ operations = ['search']
 childmodules = ['settings/portal', 'settings/portal_entry', 'settings/portal_category']
 virtual = True
 property_descriptions = {
-	'name': univention.admin.property(
-		short_description=_('Internal name'),
-		long_description='',
-		syntax=univention.admin.syntax.string_numbers_letters_dots,
-		include_in_default_search=True,
-		required=True,
-		identifies=True
-	),
-	'displayName': univention.admin.property(
-		short_description=_('Display Name'),
-		long_description='',
-		syntax=univention.admin.syntax.LocalizedDisplayName,
-		multivalue=True,
-		required=True,
-	),
+    'name': univention.admin.property(
+        short_description=_('Internal name'),
+        long_description='',
+        syntax=univention.admin.syntax.string_numbers_letters_dots,
+        include_in_default_search=True,
+        required=True,
+        identifies=True,
+    ),
+    'displayName': univention.admin.property(
+        short_description=_('Display Name'),
+        long_description='',
+        syntax=univention.admin.syntax.LocalizedDisplayName,
+        multivalue=True,
+        required=True,
+    ),
 }
 layout = [Tab(_('General'), _('Basic settings'), layout=["name"])]
 mapping = univention.admin.mapping.mapping()
 
 
 class object(univention.admin.handlers.simpleLdap):
-	module = module
+    module = module
 
 
 def lookup(co, lo, filter_s, base='', superordinate=None, scope='sub', unique=False, required=False, timeout=-1, sizelimit=0):
-	res = []
-	for child in childmodules:
-		portal_module = univention.admin.modules.get(child)
-		res.extend(portal_module.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit))
+    res = []
+    for child in childmodules:
+        portal_module = univention.admin.modules.get(child)
+        res.extend(portal_module.lookup(co, lo, filter_s, base, superordinate, scope, unique, required, timeout, sizelimit))
 
-	return res
+    return res
 
 
 def identify(dn, attr, canonical=False):
-	pass
+    pass
